package com.aucma.dms.service;

import com.aucma.dms.domain.DmsInspectRouteDetail;

import java.util.List;

/**
 * 巡检线路明细Service接口
 *
 * @author Open Platform
 * @date 2024-01-16
 */
public interface IDmsInspectRouteDetailService
{
    /**
     * 查询巡检线路明细
     *
     * @param routeDetailId 巡检线路明细主键
     * @return 巡检线路明细
     */
    public DmsInspectRouteDetail selectDmsInspectRouteDetailByRouteDetailId(Long routeDetailId);

    /**
     * 查询巡检线路明细列表
     *
     * @param dmsInspectRouteDetail 巡检线路明细
     * @return 巡检线路明细集合
     */
    public List<DmsInspectRouteDetail> selectDmsInspectRouteDetailList(DmsInspectRouteDetail dmsInspectRouteDetail);

    /**
     * 新增巡检线路明细
     *
     * @param dmsInspectRouteDetail 巡检线路明细
     * @return 结果
     */
    public int insertDmsInspectRouteDetail(DmsInspectRouteDetail dmsInspectRouteDetail);

    /**
     * 修改巡检线路明细
     *
     * @param dmsInspectRouteDetail 巡检线路明细
     * @return 结果
     */
    public int updateDmsInspectRouteDetail(DmsInspectRouteDetail dmsInspectRouteDetail);

    /**
     * 批量删除巡检线路明细
     *
     * @param routeDetailIds 需要删除的巡检线路明细主键集合
     * @return 结果
     */
    public int deleteDmsInspectRouteDetailByRouteDetailIds(Long[] routeDetailIds);

    /**
     * 删除巡检线路明细信息
     *
     * @param routeDetailId 巡检线路明细主键
     * @return 结果
     */
    public int deleteDmsInspectRouteDetailByRouteDetailId(Long routeDetailId);

    List<DmsInspectRouteDetail> selectInspectRouteListByInspectRouteId(Long inspectRouteId);
}
