package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsInspectRouteDetail;
import com.aucma.dms.service.IDmsInspectRouteDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 巡检线路明细Controller
 *
 * @author Open Platform
 * @date 2024-01-16
 */
@RestController
@RequestMapping("/dms/dmsInspectRouteDetail")
public class DmsInspectRouteDetailController extends BaseController
{

    @Autowired
    private IDmsInspectRouteDetailService dmsInspectRouteDetailService;

    /**
     * 查询巡检线路明细列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsInspectRouteDetail:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        startPage();
        List<DmsInspectRouteDetail> list = dmsInspectRouteDetailService.selectDmsInspectRouteDetailList(dmsInspectRouteDetail);
        return getDataTable(list);
    }

    /** 通过线路id查询线路明细列表*/
    @GetMapping("/selectInspectRouteListByInspectRouteId/{inspectRouteId}")
    public TableDataInfo selectInspectRouteListByInspectRouteId(@PathVariable("inspectRouteId") Long inspectRouteId){
        List<DmsInspectRouteDetail> dmsInspectRouteDetails = dmsInspectRouteDetailService.selectInspectRouteListByInspectRouteId(inspectRouteId);
        return getDataTable(dmsInspectRouteDetails);
    }
    /**
     * 导出巡检线路明细列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsInspectRouteDetail:export')" )
    ////@Log(title = "巡检线路明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        List<DmsInspectRouteDetail> list = dmsInspectRouteDetailService.selectDmsInspectRouteDetailList(dmsInspectRouteDetail);
        ExcelUtil<DmsInspectRouteDetail> util = new ExcelUtil<DmsInspectRouteDetail>(DmsInspectRouteDetail.class);
        util.exportExcel(response, list, "巡检线路明细数据");
    }

    /**
     * 获取巡检线路明细详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsInspectRouteDetail:query')" )
    @GetMapping(value = "/{routeDetailId}")
    public AjaxResult getInfo(@PathVariable("routeDetailId") Long routeDetailId)
    {
        return success(dmsInspectRouteDetailService.selectDmsInspectRouteDetailByRouteDetailId(routeDetailId));
    }

    /**
     * 新增巡检线路明细
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsInspectRouteDetail:add')" )
    ////@Log(title = "巡检线路明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        return toAjax(dmsInspectRouteDetailService.insertDmsInspectRouteDetail(dmsInspectRouteDetail));
    }

    /**
     * 修改巡检线路明细
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsInspectRouteDetail:edit')" )
    ////@Log(title = "巡检线路明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsInspectRouteDetail dmsInspectRouteDetail)
    {
        return toAjax(dmsInspectRouteDetailService.updateDmsInspectRouteDetail(dmsInspectRouteDetail));
    }

    /**
     * 删除巡检线路明细
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsInspectRouteDetail:remove')" )
    ////@Log(title = "巡检线路明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{routeDetailIds}")
    public AjaxResult remove(@PathVariable Long[] routeDetailIds)
    {
        return toAjax(dmsInspectRouteDetailService.deleteDmsInspectRouteDetailByRouteDetailIds(routeDetailIds));
    }
}
